@@ -7,28 +7,25 @@
 
 #include "kio_bookmarks.h"
 
+#include <KShell>
+#include <KLocalizedString>
+#include <KConfigGroup>
+#include <KBookmark>
+#include <KImageCache>
+#include <KFilePlacesModel>
+#include <Solid/Device>
+#include <Solid/DeviceInterface>
+#include <KIO/ApplicationLauncherJob>
+
+#include <QDebug>
+#include <QGuiApplication>
+#include <QRegularExpression>
+#include <QTextDocument>
+#include <QUrlQuery>
+
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <QRegularExpression>
-#include <qtextdocument.h>
-#include <qurlquery.h>
-
-#include <kshell.h>
-
-#include <KLocalizedString>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kbookmark.h>
-#include <kbookmarkmanager.h>
-#include <kimagecache.h>
-#include <qdebug.h>
-#include <kfileplacesmodel.h>
-#include <solid/device.h>
-#include <solid/deviceinterface.h>
-#include <QGuiApplication>
-#include <KIO/ApplicationLauncherJob>
-
 using namespace KIO;
 
 // Pseudo plugin class to embed meta data
@@ -186,7 +183,7 @@ void BookmarksProtocol::get( const QUrl& url )
             auto job = new KIO::ApplicationLauncherJob(bookmarksKCM);
             job->start();
         } else {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("Could not find bookmarks config"));
+            error(KIO::ERR_WORKER_DEFINED, i18n("Could not find bookmarks config"));
         }
         echoHead("bookmarks:/");
     } else if (path == "/editbookmarks") {
@@ -195,7 +192,7 @@ void BookmarksProtocol::get( const QUrl& url )
             auto job = new KIO::ApplicationLauncherJob(keditbookmarks);
             job->start();
         } else {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("Could not find bookmarks editor"));
+            error(KIO::ERR_WORKER_DEFINED, i18n("Could not find bookmarks editor"));
         }
         echoHead("bookmarks:/");
     } else if (path.indexOf(regexp, 0, &rmatch) >= 0) {
